@@ -28,7 +28,7 @@
 #include <KPixmapSequenceOverlayPainter>
 
 class KCupsRequest;
-class KDE_EXPORT ClassListWidget : public QListView
+class Q_DECL_EXPORT ClassListWidget : public QListView
 {
     Q_OBJECT
     Q_PROPERTY(QString selectedPrinters READ selectedPrinters WRITE setSelectedPrinters USER true)
